import AutoStoriesIcon from '@mui/icons-material/AutoStories';
import ReviewsIcon from '@mui/icons-material/Reviews';
import { Rating, Stack } from '@mui/material';
import React from 'react';
import { AutocompleteInput, Create, Datagrid, DateField, Edit, Labeled, Layout, List, NumberField, ReferenceArrayField, ReferenceField, ReferenceInput, Show, SimpleForm, SimpleList, SimpleShowLayout, TabbedShowLayout, TextField, TextInput, WithRecord, WrapperField, defaultDarkTheme, defaultLightTheme, required, useInput, } from 'react-admin';
import ResourceGuesser from '../../core/ResourceGuesser';
import FieldGuesser from '../../field/FieldGuesser';
import { HydraAdmin } from '../../hydra';
import InputGuesser from '../../input/InputGuesser';
export default {
    title: 'Admin/Custom/AdvancedCustomization',
    parameters: {
        layout: 'fullscreen',
    },
};
const BookCreate = () => (React.createElement(Create, null,
    React.createElement(SimpleForm, { sx: { maxWidth: 500 } },
        React.createElement(InputGuesser, { source: "title", helperText: false }),
        React.createElement(InputGuesser, { source: "author", helperText: false }),
        React.createElement(TextInput, { source: "description", multiline: true, helperText: false, validate: required() }),
        React.createElement(Stack, { direction: "row", gap: 2, width: "100%" },
            React.createElement(InputGuesser, { source: "isbn", label: "ISBN", helperText: false }),
            React.createElement(InputGuesser, { source: "publicationDate", helperText: false })))));
const BookEdit = () => (React.createElement(Edit, { warnWhenUnsavedChanges: true },
    React.createElement(SimpleForm, { sx: { maxWidth: 500 } },
        React.createElement(InputGuesser, { source: "title", helperText: false }),
        React.createElement(InputGuesser, { source: "author", helperText: false }),
        React.createElement(TextInput, { source: "description", multiline: true, helperText: false, validate: required() }),
        React.createElement(Stack, { direction: "row", gap: 2, width: "100%" },
            React.createElement(InputGuesser, { source: "isbn", label: "ISBN", helperText: false }),
            React.createElement(InputGuesser, { source: "publicationDate", helperText: false })))));
const BookShow = () => (React.createElement(Show, null,
    React.createElement(TabbedShowLayout, null,
        React.createElement(TabbedShowLayout.Tab, { label: "main" },
            React.createElement(TextField, { source: "title", variant: "h5" }),
            React.createElement(TextField, { source: "author", variant: "body1" }),
            React.createElement(TextField, { source: "description", variant: "body1" }),
            React.createElement(SimpleShowLayout, { direction: "row", gap: 2, sx: { p: 0 } },
                React.createElement(TextField, { source: "isbn", label: "ISBN", variant: "body1" }),
                React.createElement(DateField, { source: "publicationDate", variant: "body1" }))),
        React.createElement(TabbedShowLayout.Tab, { label: "reviews" },
            React.createElement(ReferenceArrayField, { source: "reviews", reference: "reviews", label: false },
                React.createElement(SimpleList, { primaryText: "%{body}", secondaryText: "by %{author} on %{publicationDate}", sx: { pt: 0, '& .MuiListItemButton-root': { p: 0 } }, leftAvatar: (review) => review.author
                        .split(' ')
                        .map((name) => name[0])
                        .join(''), 
                    // eslint-disable-next-line react/no-unstable-nested-components
                    tertiaryText: (review) => (React.createElement(Rating, { value: review.rating, readOnly: true, size: "small" })) }))))));
const BookList = () => (React.createElement(List, { sort: { field: 'publicationDate', order: 'DESC' } },
    React.createElement(Datagrid, null,
        React.createElement(FieldGuesser, { source: "isbn", label: "ISBN" }),
        React.createElement(FieldGuesser, { source: "title" }),
        React.createElement(FieldGuesser, { source: "author" }),
        React.createElement(FieldGuesser, { source: "publicationDate" }),
        React.createElement(NumberField, { source: "reviews.length", label: "Reviews" }))));
const RatingInput = (props) => {
    const { field } = useInput(props);
    return (React.createElement(Rating, Object.assign({}, field, { onChange: (_event, value) => {
            field.onChange(value);
        } })));
};
const filterToBookQuery = (searchText) => ({
    title: `%${searchText}%`,
});
const ReviewCreate = () => (React.createElement(Create, null,
    React.createElement(SimpleForm, { sx: { maxWidth: 500 }, defaultValues: { publicationDate: new Date() } },
        React.createElement(InputGuesser, { source: "author", helperText: false }),
        React.createElement(ReferenceInput, { source: "book", reference: "books" },
            React.createElement(AutocompleteInput, { helperText: false, filterToQuery: filterToBookQuery })),
        React.createElement(Labeled, { label: "Rating" },
            React.createElement(RatingInput, { source: "rating" })),
        React.createElement(InputGuesser, { source: "body", multiline: true, helperText: false }))));
const ReviewEdit = () => (React.createElement(Edit, { warnWhenUnsavedChanges: true },
    React.createElement(SimpleForm, { sx: { maxWidth: 500 } },
        React.createElement(InputGuesser, { source: "author", helperText: false }),
        React.createElement(ReferenceInput, { source: "book", reference: "books" },
            React.createElement(AutocompleteInput, { helperText: false, filterToQuery: filterToBookQuery })),
        React.createElement(Labeled, { label: "Rating" },
            React.createElement(RatingInput, { source: "rating" })),
        React.createElement(InputGuesser, { source: "body", multiline: true, helperText: false }),
        React.createElement(Labeled, { label: "Publication date" },
            React.createElement(DateField, { source: "publicationDate", showTime: true })))));
const ReviewShow = () => (React.createElement(Show, null,
    React.createElement(SimpleShowLayout, null,
        React.createElement(FieldGuesser, { source: "author" }),
        React.createElement(ReferenceField, { source: "book", reference: "books" }),
        React.createElement(FieldGuesser, { source: "body" }),
        React.createElement(Labeled, { label: "Rating" },
            React.createElement(WithRecord, { render: (review) => (React.createElement(Rating, { value: review.rating, readOnly: true, size: "small" })) })),
        React.createElement(DateField, { showTime: true, source: "publicationDate" }))));
const ReviewList = () => (React.createElement(List, { sort: { field: 'publicationDate', order: 'DESC' } },
    React.createElement(Datagrid, null,
        React.createElement(FieldGuesser, { source: "author" }),
        React.createElement(ReferenceField, { source: "book", reference: "books" }),
        React.createElement(WrapperField, { label: "Rating" },
            React.createElement(WithRecord, { render: (review) => (React.createElement(Rating, { value: review.rating, readOnly: true, size: "small" })) })),
        React.createElement(DateField, { showTime: true, source: "publicationDate" }))));
export const AdvancedCustomization = () => (React.createElement(HydraAdmin, { entrypoint: process.env.ENTRYPOINT, layout: Layout, theme: defaultLightTheme, darkTheme: defaultDarkTheme },
    React.createElement(ResourceGuesser, { name: "books", list: BookList, show: BookShow, edit: BookEdit, create: BookCreate, recordRepresentation: "title", icon: AutoStoriesIcon }),
    React.createElement(ResourceGuesser, { name: "reviews", list: ReviewList, show: ReviewShow, edit: ReviewEdit, create: ReviewCreate, recordRepresentation: "id", icon: ReviewsIcon })));
//# sourceMappingURL=AdvancedCustomization.stories.js.map